@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2012-2014 Aurimas Cernius
+ * Copyright (C) 2010,2012-2015 Aurimas Cernius
  * Copyright (C) 2009 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -52,6 +52,7 @@ typedef std::map<std::string, AddinInfo> AddinInfoMap;
 class AddinManager
 {
 public:
+
   AddinManager(NoteManager & note_manager, const std::string & conf_dir);
   ~AddinManager();
 
@@ -64,6 +65,7 @@ public:
     }
 
   void load_addins_for_note(const Note::Ptr &);
+  std::vector<NoteAddin*> get_note_addins(const Note::Ptr &) const;
   ApplicationAddin *get_application_addin(const std::string & id) const;
   sync::SyncServiceAddin *get_sync_service_addin(const std::string & id) const;
   void get_preference_tab_addins(std::list<PreferenceTabAddin *> &) const;
@@ -93,6 +95,7 @@ private:
   void add_module_addins(const std::string & mod_id, sharp::DynamicModule * dmod);
   AddinInfo get_info_for_module(const std::string & module) const;
   void on_setting_changed(const Glib::ustring & key);
+  void register_addin_actions() const;
     
   NoteManager & m_note_manager;
   const std::string m_gnote_conf_dir;
